<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author José Carlos Monteiro <jose.c.monteiro@netcabo.pt>
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Fil <fil@meteopt.com>
 * @author André Neves <drakferion@gmail.com>
 * @author José Campos zecarlosdecampos@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar página';
$lang['btn_source']            = 'Ver fonte';
$lang['btn_show']              = 'Ver página';
$lang['btn_create']            = 'Criar página';
$lang['btn_search']            = 'Pesquisar';
$lang['btn_save']              = 'Gravar';
$lang['btn_preview']           = 'Prever';
$lang['btn_top']               = 'Voltar ao topo';
$lang['btn_newer']             = '<< mais recente';
$lang['btn_older']             = 'menos recente >>';
$lang['btn_revs']              = 'Revisões';
$lang['btn_recent']            = 'Alt. Recentes';
$lang['btn_upload']            = 'Carregar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Entrar';
$lang['btn_logout']            = 'Sair';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Actualizar';
$lang['btn_delete']            = 'Apagar';
$lang['btn_back']              = 'Voltar';
$lang['btn_backlink']          = 'Backlinks';
$lang['btn_backtomedia']       = 'Voltar à Selecção de Media';
$lang['btn_subscribe']         = 'Subscrever Alterações';
$lang['btn_profile']           = 'Actualizar Perfil';
$lang['btn_reset']             = 'Limpar';
$lang['btn_draft']             = 'Editar rascunho';
$lang['btn_recover']           = 'Recuperar rascunho';
$lang['btn_draftdel']          = 'Apagar rascunho';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Registar';
$lang['btn_apply']             = 'Aplicar';
$lang['btn_media']             = 'Gestor de Media';
$lang['btn_deleteuser']        = 'Remover a Minha Conta';
$lang['loggedinas']            = 'Está em sessão como';
$lang['user']                  = 'Utilizador';
$lang['pass']                  = 'Senha';
$lang['newpass']               = 'Nova senha';
$lang['oldpass']               = 'Confirme senha actual';
$lang['passchk']               = 'Confirmar novamente';
$lang['remember']              = 'Memorizar?';
$lang['fullname']              = 'Nome completo';
$lang['email']                 = 'Email';
$lang['profile']               = 'Perfil do Utilizador';
$lang['badlogin']              = 'O utilizador inválido ou senha inválida.';
$lang['minoredit']             = 'Alterações Menores';
$lang['draftdate']             = 'Rascunho automaticamente gravado em';
$lang['nosecedit']             = 'A página foi modificada entretanto. Como a informação da secção estava desactualizada, foi carregada a página inteira.';
$lang['regmissing']            = 'Por favor, preencha todos os campos.';
$lang['reguexists']            = 'Este utilizador já está inscrito. Por favor escolha outro nome de utilizador.';
$lang['regsuccess']            = 'O utilizador foi criado e a senha foi enviada para o endereço de correio electrónico usado na inscrição.';
$lang['regsuccess2']           = 'O utilizador foi criado.';
$lang['regmailfail']           = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
$lang['regbadmail']            = 'O endereço de correio electrónico é inválido. Se o endereço está correcto, e isto é um erro, por favor, contacte o administrador!';
$lang['regbadpass']            = 'As duas senhas não são idênticas, por favor tente de novo.';
$lang['regpwmail']             = 'A sua senha DokuWiki';
$lang['reghere']               = 'Para se registar, clique em';
$lang['profna']                = 'Este Wiki não suporta modificações aos perfis.';
$lang['profnochange']          = 'Nada alteração, nada a fazer.';
$lang['profnoempty']           = 'Não são permitidos nomes ou endereços em branco.';
$lang['profchanged']           = 'Perfil do utilizador actualizado com sucesso.';
$lang['profnodelete']          = 'Esta wiki não suporta remoção de utilizadores';
$lang['profdeleteuser']        = 'Apagar Conta';
$lang['profdeleted']           = 'A sua conta de utilizador foi removida desta wiki';
$lang['pwdforget']             = 'Esqueceu a sua senha? Pedir nova senha';
$lang['resendna']              = 'Este wiki não suporta reenvio de senhas.';
$lang['resendpwdmissing']      = 'É preciso preencher todos os campos.';
$lang['resendpwdnouser']       = 'Não foi possível encontrar este utilizador.';
$lang['resendpwdbadauth']      = 'O código de autenticação não é válido. Por favor, assegure-se de que o link de confirmação está completo.';
$lang['resendpwdconfirm']      = 'O link de confirmação foi enviado por e-mail.';
$lang['resendpwdsuccess']      = 'A nova senha foi enviada por e-mail.';
$lang['license']               = 'Excepto menção em contrário, o conteúdo neste wiki está sob a seguinte licença:';
$lang['licenseok']             = 'Nota: Ao editar esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
$lang['searchmedia']           = 'Procurar nome de ficheiro:';
$lang['searchmedia_in']        = 'Procurar em %s';
$lang['txt_upload']            = 'Escolha ficheiro para carregar';
$lang['txt_filename']          = 'Carregar como (opcional)';
$lang['txt_overwrt']           = 'Escrever por cima do ficheiro já existente';
$lang['lockedby']              = 'Bloqueado por';
$lang['lockexpire']            = 'Expira em';
$lang['js']['willexpire']      = 'O bloqueio de edição para este documento irá expirar num minuto.\nPara evitar conflitos use o botão Prever para re-iniciar o temporizador de bloqueio.';
$lang['js']['notsavedyet']     = 'Alterações não gravadas serão perdidas.';
$lang['js']['searchmedia']     = 'Procurar por ficheiros';
$lang['js']['keepopen']        = 'Mantenha a janela aberta durante a selecção';
$lang['js']['hidedetails']     = 'Esconder Detalhes';
$lang['js']['mediatitle']      = 'Propriedades de ligação';
$lang['js']['mediadisplay']    = 'Tipo de ligação';
$lang['js']['mediaalign']      = 'Alinhamento';
$lang['js']['mediasize']       = 'Tamanho da imagem';
$lang['js']['mediatarget']     = 'Alvo da ligação';
$lang['js']['mediaclose']      = 'Fechar';
$lang['js']['mediainsert']     = 'Inserir';
$lang['js']['mediadisplayimg'] = 'Mostrar a imagem';
$lang['js']['mediadisplaylnk'] = 'Mostrar apenas a ligação';
$lang['js']['mediasmall']      = 'Versão pequena';
$lang['js']['mediamedium']     = 'Versão média';
$lang['js']['medialarge']      = 'Versão grande';
$lang['js']['mediaoriginal']   = 'Versão original';
$lang['js']['medialnk']        = 'Ligação para a página de detalhe';
$lang['js']['mediadirect']     = 'Ligação directa para o original';
$lang['js']['medianolnk']      = 'Nenhuma ligação';
$lang['js']['medianolink']     = 'Não ligar à imagem';
$lang['js']['medialeft']       = 'Alinhar a imagem à esquerda.';
$lang['js']['mediaright']      = 'Alinhar a imagem à direita.';
$lang['js']['mediacenter']     = 'Alinhar a imagem ao centro.';
$lang['js']['medianoalign']    = 'Não usar alinhamento algum.';
$lang['js']['nosmblinks']      = 'Ligação a pastas Windows partilhadas apenas funciona com o Microsoft Internet Explorer.
Pode no entanto copiar e colar o link.';
$lang['js']['linkwiz']         = 'Assistente de Criação de Ligação';
$lang['js']['linkto']          = 'Ligação para:';
$lang['js']['del_confirm']     = 'Remover o(s) item(s) selecionados?';
$lang['js']['restore_confirm'] = 'Restaurar esta versão?';
$lang['js']['media_diff']      = 'Ver diferenças:';
$lang['js']['media_diff_both'] = 'Lado a Lado';
$lang['js']['media_diff_opacity'] = 'Sobreposição';
$lang['js']['media_diff_portions'] = 'Slider';
$lang['js']['media_select']    = 'Selecione ficheiros…';
$lang['js']['media_upload_btn'] = 'Enviar';
$lang['js']['media_done_btn']  = 'Feito';
$lang['js']['media_drop']      = 'Largue ficheiros aqui para enviar';
$lang['js']['media_cancel']    = 'remover';
$lang['js']['media_overwrt']   = 'Escrever por cima de ficheiros existentes';
$lang['rssfailed']             = 'Ocorreu um erro neste canal RSS: ';
$lang['nothingfound']          = 'Nada foi encontrado.';
$lang['mediaselect']           = 'Selecção de ficheiros';
$lang['fileupload']            = 'Carregamento de ficheiros';
$lang['uploadsucc']            = 'Carregamento com sucesso';
$lang['uploadfail']            = 'Falhou o carregamento. Talvez por não ter permissões?';
$lang['uploadwrong']           = 'Carregamento negado. Esta extensão está proibida.';
$lang['uploadexist']           = 'O ficheiro já existe. Não pode ser carregado.';
$lang['uploadbadcontent']      = 'O conteúdo carregado não corresponde à extensão %s.';
$lang['uploadspam']            = 'O carregamento foi bloqueado pela lista negra de SPAM.';
$lang['uploadxss']             = 'O carregamento foi bloqueado porque possivelmente contem conteúdo malicioso.';
$lang['uploadsize']            = 'O ficheiro carregado é demasiado grande. (máx. %s)';
$lang['deletesucc']            = 'O ficheiro "%s" foi removido.';
$lang['deletefail']            = 'O ficheiro "%s" não pode ser removido, por favor verifique as permissões.';
$lang['mediainuse']            = 'O ficheiro "%s" não foi removido porque está ainda a ser usado.';
$lang['namespaces']            = 'Grupos';
$lang['mediafiles']            = 'Ficheiros disponíveis em';
$lang['accessdenied']          = 'Não tem permissão para ver esta página.';
$lang['mediausage']            = 'Use a seguinte sintaxe para referenciar este ficheiro:';
$lang['mediaview']             = 'Ver ficheiro original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Carregar ficheiros para o grupo actual aqui. Para criar sub-grupos: escrever o nome do sub-grupo seguido de : antes do nome do ficheiro no campo "Carregar como".';
$lang['mediaextchange']        = 'Extensão alterada de .%s para .%s!';
$lang['reference']             = 'Referências para';
$lang['ref_inuse']             = 'O ficheiro não pode ser removido, porque está ainda a ser usado nestes documentos:';
$lang['ref_hidden']            = 'Algumas referências estão em documentos para os quais não tem permissão para ler';
$lang['hits']                  = 'Resultados';
$lang['quickhits']             = 'Documentos encontrados';
$lang['toc']                   = 'Tabela de Conteúdos';
$lang['current']               = 'Actual';
$lang['yours']                 = 'A sua versão';
$lang['diff']                  = 'mostrar diferenças com a versão actual';
$lang['diff2']                 = 'mostrar diferenças entre versões escolhidas';
$lang['difflink']              = 'Ligação para esta vista de comparação';
$lang['diff_type']             = 'Ver diferenças';
$lang['diff_inline']           = 'Embutido';
$lang['diff_side']             = 'Lado a lado';
$lang['line']                  = 'Linha';
$lang['breadcrumb']            = 'Está em';
$lang['youarehere']            = 'Está aqui';
$lang['lastmod']               = 'Esta página foi modificada pela última vez em';
$lang['by']                    = 'por';
$lang['deleted']               = 'Documento automaticamente removido.';
$lang['created']               = 'Criação deste novo documento.';
$lang['restored']              = 'Versão anterior restaurada (%s)';
$lang['external_edit']         = 'Edição externa';
$lang['summary']               = 'Sumário da Edição';
$lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
$lang['download']              = 'Descarregar Snippet';
$lang['tools']                 = 'Ferramentas';
$lang['user_tools']            = 'Ferramentas de Utilizador';
$lang['site_tools']            = 'Ferramentas de Site';
$lang['page_tools']            = 'Ferramentas de Página';
$lang['skip_to_content']       = 'saltar para conteúdo';
$lang['sidebar']               = 'Barra Lateral';
$lang['mail_newpage']          = 'documento adicionado:';
$lang['mail_changed']          = 'documento modificado:';
$lang['mail_subscribe_list']   = 'páginas alteradas no espaço de nome:';
$lang['mail_new_user']         = 'Novo utilizador:';
$lang['mail_upload']           = 'Ficheiro carregado:';
$lang['changes_type']          = 'Ver alterações de';
$lang['pages_changes']         = 'Páginas';
$lang['media_changes']         = 'Ficheiros Media';
$lang['both_changes']          = 'Tanto páginas como ficheiros media';
$lang['qb_bold']               = 'Texto com Ênfase';
$lang['qb_italic']             = 'Texto Itálico';
$lang['qb_underl']             = 'Texto Sublinhado';
$lang['qb_code']               = 'Texto Código';
$lang['qb_strike']             = 'Texto Riscado';
$lang['qb_h1']                 = 'Cabeçalho Nível 1';
$lang['qb_h2']                 = 'Cabeçalho Nível 2';
$lang['qb_h3']                 = 'Cabeçalho Nível 3';
$lang['qb_h4']                 = 'Cabeçalho Nível 4';
$lang['qb_h5']                 = 'Cabeçalho Nível 5';
$lang['qb_h']                  = 'Cabeçalho';
$lang['qb_hs']                 = 'Seleccionar Cabeçalho';
$lang['qb_hplus']              = 'Cabeçalho Maior';
$lang['qb_hminus']             = 'Cabeçalho Menor';
$lang['qb_hequal']             = 'Cabeçalho de Nível Semelhante';
$lang['qb_link']               = 'Ligação Interna';
$lang['qb_extlink']            = 'Ligação Externa';
$lang['qb_hr']                 = 'Barra Horizontal';
$lang['qb_ol']                 = 'Item numa Lista Ordenada';
$lang['qb_ul']                 = 'Item numa Lista Não Ordenada';
$lang['qb_media']              = 'Incluir imagens e outros ficheiros';
$lang['qb_sig']                = 'Inserir Assinatura';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Caracteres Especiais';
$lang['upperns']               = 'Ir para o espaço de nomes parente';
$lang['admin_register']        = 'Registar Novo Utilizador';
$lang['metaedit']              = 'Editar Metadata';
$lang['metasaveerr']           = 'Falhou a escrita de Metadata';
$lang['metasaveok']            = 'Metadata gravada';
$lang['img_backto']            = 'De volta a';
$lang['img_title']             = 'Título';
$lang['img_caption']           = 'Legenda';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Ficheiro';
$lang['img_fsize']             = 'Tamanho';
$lang['img_artist']            = 'Fotógrafo';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formato';
$lang['img_camera']            = 'Câmara';
$lang['img_keywords']          = 'Palavras-Chave';
$lang['img_width']             = 'Largura';
$lang['img_height']            = 'Altura';
$lang['img_manager']           = 'Ver em gestor de media';
$lang['subscr_subscribe_success'] = 'Adicionado %s à lista de subscrição para %s';
$lang['subscr_subscribe_error'] = 'Erro ao adicionar %s à lista de subscrição para %s';
$lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de utilizador, não pode ser adicionado à lista de subscrição';
$lang['subscr_unsubscribe_success'] = 'Removido %s da lista de subscrição para %s';
$lang['subscr_unsubscribe_error'] = 'Erro ao remover %s da lista de subscrição para %s';
$lang['subscr_already_subscribed'] = '%s já está subscrito em %s';
$lang['subscr_not_subscribed'] = '%s não está subscrito em %s';
$lang['subscr_m_not_subscribed'] = 'Não está subscrito à página ou espaço de nome corrente.';
$lang['subscr_m_new_header']   = 'Adicionar subscrição';
$lang['subscr_m_current_header'] = 'Subscrições correntes';
$lang['subscr_m_unsubscribe']  = 'Des-subscrever';
$lang['subscr_m_subscribe']    = 'Subscrever';
$lang['subscr_m_receive']      = 'Receber';
$lang['subscr_style_every']    = 'email em qualquer alteração';
$lang['subscr_style_digest']   = '"digest email" de alterações em cada página (cada %.2f dias)';
$lang['subscr_style_list']     = 'lista de páginas alteradas desde o último email (cada %.2f dias)';
$lang['authtempfail']          = 'Autenticação temporariamente indisponível. Se a situação persistir, por favor informe o Wiki Admin.';
$lang['authpwdexpire']         = 'A sua senha expirará dentro de %d dias, deve mudá-la em breve.';
$lang['i_chooselang']          = 'Escolha a linguagem';
$lang['i_installer']           = 'Instalador do DokuWiki';
$lang['i_wikiname']            = 'Nome Wiki';
$lang['i_enableacl']           = 'Activar ACL (recomendado)';
$lang['i_superuser']           = 'Super-utilizador';
$lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados mais abaixo. Não pode continuar até que sejam corrigidos.';
$lang['i_modified']            = 'Por razões de segurança, este script só funciona em novas e não-modificadas instalações do Dokuwiki. Deve por isso re-extrair os ficheiros do pacote que descarregou ou então deve consultar as completas <a href="http://dokuwiki.org/install">instruções de instalação do Dokuwiki installation instructions</a>';
$lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. Terá o serviço de alojamento desactivado-a por alguma razão?';
$lang['i_phpver']              = 'A versão de PHP actual <code>%s</code> é inferior à versão mínima <code>%s</code>. É preciso actualizar a instalação PHP.';
$lang['i_permfail']            = '<code>%s</code> não permite que o DokuWiki escreva nela. É preciso corrigir as permissões desta pasta!';
$lang['i_confexists']          = '<code>%s</code> já existe';
$lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É preciso verificar as permissões e criar o ficheiro manualmente.';
$lang['i_badhash']             = 'dokuwiki.php não é o original ou não é reconhecido (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor ilegal ou vazio';
$lang['i_success']             = 'A instalação e configuração inicial foram bem sucedidas. Pode remover o install.php. Aceda ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> a correr o DokuWiki.';
$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos ficheiros de configuração. Poderá ser preciso corrigi-los manualmente antes de poder aceder ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> a correr o DokuWiki.';
$lang['i_policy']              = 'Politica ACL inicial';
$lang['i_pol0']                = 'Wiki Aberto (ler, escrever e carregar para todos)';
$lang['i_pol1']                = 'Wiki Público (ler para todos, escrever e carregar para utilizadores inscritos)';
$lang['i_pol2']                = 'Wiki Fechado (ler, escrever e carregar somente para utilizadores inscritos)';
$lang['i_retry']               = 'Repetir';
$lang['i_license']             = 'Por favor escolha a licença sob a qual quer colocar o seu conteúdo:';
$lang['i_license_none']        = 'Não mostrar nenhuma informação de licença';
$lang['i_pop_field']           = 'Por favor ajude-nos a melhorar a experiência Dokuwiki:';
$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anónimos de uso para os desenvolvedores DokuWiki';
$lang['recent_global']         = 'Você está a observar as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
$lang['years']                 = '%d anos atrás';
$lang['months']                = '%d meses atrás';
$lang['weeks']                 = '%d semanas atrás';
$lang['days']                  = '%d dias atrás';
$lang['hours']                 = '%d horas atrás';
$lang['minutes']               = '%d minutos atrás';
$lang['seconds']               = '%d segundos atrás';
$lang['wordblock']             = 'A sua alteração não foi guardada porque contém texto bloqueado (spam).';
$lang['media_uploadtab']       = 'Enviar';
$lang['media_searchtab']       = 'Procurar';
$lang['media_file']            = 'Ficheiro';
$lang['media_viewtab']         = 'Ver';
$lang['media_edittab']         = 'Editar';
$lang['media_historytab']      = 'Histórico';
$lang['media_list_rows']       = 'Linhas';
$lang['media_sort_name']       = 'Ordenar por nome';
$lang['media_sort_date']       = 'Ordenar por data';
$lang['media_files']           = 'Ficheiros em %s';
$lang['media_upload']          = 'Enviar para o grupo <strong>%s</strong>.';
$lang['media_search']          = 'Procurar no grupo <strong>%s</strong>.';
$lang['media_view']            = '%s';
$lang['media_edit']            = 'Editar %s';
$lang['media_history']         = 'Histórico do %s';
$lang['media_meta_edited']     = 'metadata editada';
$lang['media_perm_read']       = 'Perdão, não tem permissão para ler ficheiros.';
$lang['media_perm_upload']     = 'Perdão, não tem permissão para enviar ficheiros.';
$lang['media_update']          = 'enviar nova versão';
$lang['media_restore']         = 'Restaurar esta versão';
